function OUT = CmCd(Hs,Tp,D,h)
% OUT = CmCd(Hs,Tp,D,h)
% Input:  Hs, Tp, structure diameter, water depth
% Output: OUT is a structure with the given fields: Cm, Cd, KS, LAM, H
% Calculates mass coefficient, drag coefficient, Keulagan Carpenter-number
% Returns the wave length and wave height used in the calculation.
% Call: OUT = MaxWaves(Hs,Tp,h,30)



cd ..
%% Modified Rayleigh by Nss
cd statistics
OUT = MaxWaves(Hs,Tp,h,30*60);
H = OUT.Naess;
clear OUT
T = 0.9*Tp;

%% Calculation of the 3rd order horizontal wave acceleration 
%  amplitudes at z = 0, and wave profiles at different water depth. 
cd regular
Zvec = [-1 0 1];
Tvec = 0:0.01:T;
stokes3rd;
Umax = max(max(THI.U)); % maximum orbital particle velocity

%% Marine growth, new diameter!
t = 0.1;   % Taken from DNV loads 6.7.4.2
D = D+2*t;

%% KC-number
KC = Umax*T/D;

%% Drag coefficient in steady flow
k = mean([0.005 0.05]);  % Surface roughness
r = k/D;                 % roughness ratio
if     r < 10^(-4)
    Cds = 0.65;
elseif r > 10^(-2)
    Cds = 1.05;
else
    Cds = (29+4*log10(r))/20;
end

%% Effect of flow oscillations
%  6.7.2 - Effect of KC number, psi = wake amplification factor
Cpi = 1.5 - 0.024*(12/Cds-10);
if     KC <= 0.75
    psi = Cpi-1-2*(KC-0.75);
elseif KC <  2
    psi = Cpi-1;
else
    psi = Cpi+0.1*(KC-12);
end
Cd = Cds*psi;

%% Mass coefficient
if KC < 3
    Cm = 2;
else
    Cm = max(2-0.044*(KC-3) , 1.6-(Cds-0.65));
end

%% Output
OUT.Cm  = Cm;
OUT.Cd  = Cd;
OUT.KC  = KC;
OUT.lam = lam;
OUT.H   = H;