function OUT = MaxWaves(Hs,Tp,h,dur)
% OUT = MaxWaves(Hs,Tp,h,dur)
% Input:  Hs, Tp, water depth, time duration
% Output: OUT is a structure with the given fields: rayleigh, Naess, forristall
% Calculate wave heights from different PDF, acoording to the most
% probable wave in a duration specified by "dur"
% The wave is determined by Naess dist. as the most likely wave to occur
% Call: [S,W] = WaveSpectra(Hs,Tp,Tvec,Wmax,2);
%           K = wave_number(W,h);
cd ..

% Wave spectra
g = 9.81;
cd irregular_sea;
Wmax = sqrt(2*g/Hs)*4;
Tvec = [0:Tp/50:Tp*100];
[S,W] = WaveSpectra(Hs,Tp,Tvec,Wmax,2);

% Determine probability level
w1  = trapz(W,W.*S)/trapz(W,S);
T1  = 2*pi/w1;
N   = dur/T1;
P   = 1/N; clear N dur

% Wave numbers
cd diverse;
K = wave_number(W,h);

% Rayleigh
a = Hs/sqrt(2);
OUT.rayleigh = sqrt(-log(P))*a;

% Rayleig, Nss rho (r)
a    = 0.036 - 0.0056*Tp/sqrt(Hs);
gam  = exp(3.484*(   1-0.1975*a*Tp^4/Hs^2   ));
r    = -0.000191*gam^3 + 0.00488*gam^2 - 0.0525*gam - 0.605;
a    = Hs*(  0.5*sqrt(1-r) );
OUT.Naess = sqrt(-log(P))*a;

% Forristall (Weibull)
w1  = trapz(W,W.*S)/trapz(W,S);
T1  = 2*pi/w1;
S1  = 2*pi*Hs/(g*T1^2);
k1  = w1^2/g;
Urs = Hs/(k1^2*h^3);
a   = Hs*( 0.3536+0.2892*S1+0.1060*Urs  );
b   =      2     -2.1597*S1+0.0968*Urs^2 ;
OUT.forristall = (-log(P))^(1/b)*a;