%% Morison equation
function FM = morison1(Cm,Cd,D,h,Zvec,U,A)
% FM = morison1(Cm,Cd,D,h,Zvec,U,A)
% Input: h = depth, U = velocity matrix, A = acceleration matrix, Zvec =
% coordinates corresponding to kinematic matrices
% Output: FM(1,:) = base shear force, FM(2,:) = overturning moment
% Calculates forces from wave kinematics using Morison:
% Fdist = rho*Cm*pi*D^2/4*A + rho*D/2*Cd*U.*abs(U); 
% trapezoidal rule, by   FM(1,:)=trapz(Zvec,Fdist(:,i))  for each time step i
cd ..
rho  = 1025;
g    = 9.81;
Zvec = Zvec';

Fdist= rho*Cm*pi*D^2/4*A + rho*D/2*Cd*U.*abs(U);        % load per meter

for i = 1:length(Fdist(1,:))
    FM(1,i) = trapz(Zvec,Fdist(:,i)); % Force
	temp    = Fdist(:,i).*(Zvec+h);
    FM(2,i) = trapz(Zvec,temp);       % Moment
end