function out = morison2(Cm,Cd,D,h,Zvec,eta,U,A)
% out = morison2(Cm,Cd,D,h,Zvec,eta,U,A)
% Input: h = depth, U = velocity matrix, A = acceleration matrix, Zvec =
% coordinates corresponding to kinematic matrices, eta = surface elevation
% Output: out(1,:) = base shear force, out(2,:) = overturning moment
% Calculates forces from wave kinematics using Morison with trapz(), includes the free
% surface elevation!


cd ..
rho  = 1025;
g    = 9.81;
Fdist= rho*Cm*pi*D^2/4*A + rho*D/2*Cd*U.*abs(U); % distributed load

% Integration to z=0, if linear, deep2 or secfin!
temp = size(Fdist);
if temp(1) == length(Zvec)
    temp = max(find(Zvec<=0));
    Fsur = Fdist(temp,:);
    eta  = Fsur*0;
else
    Fsur = Fdist(1,:);
    Fdist(1,:) = [];
end

% Integration to actual elevation!
out = Fdist(1:2,:)*0;
for i = 1:length(Fdist(1,:))
    loc    = max(find(Zvec<eta(i))); % highest submerged point on monopile
    Znew   = [ Zvec(1:loc)     eta(i)];
    Fnew   = [Fdist(1:loc,i)' Fsur(i)];
    % Force
    out(1,i) = trapz(Znew,Fnew);
    % Moment
    out(2,i) = trapz(Znew,(Znew+h).*Fnew);
end