function out = morisonS2(Cm,Cd,D,h,Zvec,eta,U,A)
% out = morisonS2(Cm,Cd,D,h,Zvec,eta,U,A)
% See morison2.m
% This function do the same, but the distributed loads will be interpolated
% by spline() before the trapz() is applied
cd ..
N    = length(Zvec)*5;
rho  = 1025;
g    = 9.81;
Fdist= rho*Cm*pi*D^2/4*A + rho*D/2*Cd*U.*abs(U); % distributed load

% Integration to z=0, if linear, deep2 or secfin!
temp = size(Fdist);
if temp(1) == length(Zvec)
    temp = max(find(Zvec<=0));
    Fsur = Fdist(temp,:);
    eta  = Fsur*0;
else
    Fsur = Fdist(1,:);
    Fdist(1,:) = [];
end

% Integration to actual elevation!
out = Fdist(1:2,:)*0;
for i = 1:length(Fdist(1,:))
    loc  = max(find(Zvec<eta(i))); % highest submerged point on monopile
    Znew = (1-((N:-1:1)/N).^2)*(h+eta(i))-h;
    Fnew = spline([Zvec(1:loc) eta(i)],[Fdist(1:loc,i)' Fsur(i)],Znew);
    % Force
    out(1,i) = trapz(Znew,Fnew);
    % Moment
    out(2,i) = trapz(Znew,(Znew+h).*Fnew);
end