%% Morison equation
function out = morisonSL(Cm,Cd,D,h,Zvec,eta,U,A,Zstr)
% out = morisonSL(Cm,Cd,D,h,Zvec,eta,U,A,Zstr)
% See morisonS2.m
% This function do the same, but the distributed loads is lumped to the
% nodes specified in Zstr (which do not need to correspond to Zvec, the vertical coordinates of calculated kinematics)
cd ..
N    = length(Zstr)*5;
Pdist= (1-((N:-1:1)/N).^2);
rho  = 1025;
g    = 9.81;

Fdist= rho*Cm*pi*D^2/4*A + rho*D/2*Cd*U.*abs(U);        % load per meter

% Integration to z=0, if linear, deep2 or secfin!
temp = size(Fdist);
if temp(1) == length(Zvec)
    temp = max(find(Zvec<=0));
    Fsur = Fdist(temp,:);
    eta  = Fsur*0;
else
    Fsur = Fdist(1,:);
    Fdist(1,:) = [];
end

out = zeros(length(Zstr),length(Fsur));
for i = 1:length(Fdist(1,:))
           lcI = max(find(Zvec<eta(i))); % highest submerged point from kinematic calculations
           lcS = max(find(Zstr<eta(i))); % highest submerged point on the structure
          Znew = Pdist*(h+eta(i))-h;
          Fnew = spline([Zvec(1:lcI) eta(i)],[Fdist(1:lcI,i)' Fsur(i)],Znew);     
            l1 = 1;
            l2 = max(find(Znew<=(Zstr(2)+Zstr(1))/2));
      out(1,i) = trapz(Znew(l1:l2),Fnew(l1:l2));
    for j = 2:(lcS-1)
            l1 = l2;
            l2 = max(find(Znew<=(Zstr(j+1)+Zstr(j))/2));
      out(j,i) = trapz(Znew(l1:l2), Fnew(l1:l2));
    end
    out(lcS,i) = trapz(Znew(l2:end), Fnew(l2:end));
end