%% Embedded stream function
function OUT = ExtractSeries(Tvec,Z,Tcutoff,dt,choice)
% OUT = ExtractSeries(Tvec,Z,Tcutoff,dt,choice)
% Input:  Time vector, Surface elevation vector, Time to include before and after the
% embedding location, time step, choice:
%          1 = max crest to min through, 2 = max crest to mean through, 
%          3 = max height
% Output: OUT is a structure with the given fields: H, T, Tvec, Z
%           H = wave height, T = wave period, Tvec = new time vector, Z
%           corresponding surface elevation
cd ..

temp = floor(Tcutoff/dt);

if find(choice < 3)
    % Cut out time series around the max Ac-wave
    [H N0] = max(    Z(1+temp:end-temp)  );  % inside given duration sea state
else
    % Cut out time series around the max H-wave
    cd diverse;
    [H N0] = findH(  Z(1+temp:end-temp)  );  % inside given duration sea state
end
N0   = N0 + temp;                            % inside extended duration sea state
Z    =    Z(1,-temp+N0:temp+N0);             % cut out the wanted sea about event
Tvec = Tvec(1,-temp+N0:temp+N0);             % get the belonging time vector, which we will use to find wave kinematics

% Determine wave period      % length = odd.. assume odd = 9, then -->
N0   = ceil(length(Z)/2);    % 9/2 = 4.5.. N0 in Znew becomes 5!
temp = sign(Z(1:end-1).*Z(2:end));
temp = (temp-1)/(-2);
temp = find(temp==1);
N    = find(temp>N0);
T    = dt*(temp(N(2))-temp(N(1)-2))/1.5;

% Determine wave hight
if find(choice < 3)
    temp1 = Z( temp(N(1))   : temp(N(2)) );
    Zmin  =  min(temp1);
    temp1 = Z( temp(N(1)-2) : temp(N(1)-1) );
    if choice == 1
        Zmin  =  min([min(temp1) Zmin]);
        H     = H - Zmin;
    else
        Zmin  = mean([min(temp1) Zmin]);
        H     = H - Zmin;
    end
end

% Output structure
OUT.H    = H;
OUT.T    = T;
OUT.Tvec = Tvec;
OUT.Z    = Z;