%% Blend stream function with irregular sea
function [Mnew Mirr] = blend2(Tvec,Tirr,Mirr,Tstr,Mstr)
% Tvec = Time vector from irregular time series
% [Mnew Mirr] = blend2(Tvec,Tirr,Mirr,Tstr,Mstr)
% See blend.m  --> Input:  Mirr = Zirr, Mstr = Zemb
%                  Output: Mew = Znew
% This function do the same, but the Stream function wave period (Tstr) can now be
% different from the irregular Period (Tirr). Mirr is the stochastic matrix
% adapted to the wave period Tstr



dt   = Tvec(2)-Tvec(1);
NosZ = length(Mirr(:,1));
Nadd = floor((Tstr-Tirr)/dt/2);  % added time steps
NosT = length(-Nadd:Nadd);
if Tstr > Tirr
    temp = find(Tvec==0);
    Tvec = [Tvec(  Nadd+1:temp-1)-Nadd*dt (-Nadd:Nadd)*dt Tvec(temp+1:end-Nadd)+Nadd*dt];
    Mirr = [Mirr(:,Nadd+1:temp-1)     zeros(NosZ,NosT)  Mirr(:,temp+1:end-Nadd)];
end

Mnew = Mirr*0;
for i = 1:length(Tvec)
    t = Tvec(i);
    if     t < -0.75*Tstr
        Firr = 1;
        Femb = 0;
    elseif t >  0.75*Tstr
        break
    elseif  abs(t) < 0.5*Tstr
        Firr = 0;
        Femb = 1;
    else
        Firr = 0.5-0.5*cos(  4*pi*(abs(t)/Tstr-0.5)  );
        Femb = 0.5+0.5*cos(  4*pi*(abs(t)/Tstr-0.5)  );
    end
    Mnew(:,i) = Mirr(:,i)*Firr + Mstr(:,i)*Femb;
end
Mnew(:,i:end) = Mirr(:,i:end);