function [Utot,Atot,SEC] = K2deep2(SEC,U,A,Tvec,Zvec,h,nr)
% Calculated second order kinematic at deep water

g  = 9.81;
W  = SEC.W;
Za = SEC.Za;
eps= SEC.eps;
% Deep water dispersion
K     = W.^2/g;
% Matrices:
Dneg = zeros(length(W));  Wneg = Dneg; 
Eneg = Dneg;              Kneg = Dneg;
for i = 1:(length(W)-1)       % i = n --> In Johannessen
    for j = (i+1):length(W)   % j = m --> In Johannessen, then j > i
        Wneg(i,j) =   W(j) -   W(i);
        Eneg(i,j) = eps(j) - eps(i);
        Kneg(i,j) =   K(j) -   K(i);
        Dneg(i,j) = Za(i)*Za(j)*Kneg(i,j)*W(j);
    end
end
dU  = zeros(length(Zvec),length(Tvec)); dA = dU;
for i = 1:length(Zvec)
    z    = Zvec(i); [nr z]
    temp1 = -Dneg.*exp(Kneg*z);  % minus sign!
    temp2 = W.*Za.*exp(K   *z);
    if z > 0; break; end
    for j = 1:length(Tvec)
        t       =   Tvec(j);
       %Second order horizontal deep velocity and acceleration correction
        dU(i,j) =  sum(sum(        temp1.*cos(-Wneg*t + Eneg) )  );
        dA(i,j) =  sum(sum( -Wneg.*temp1.*sin(-Wneg*t + Eneg) )  );
        Wvel    =      sum(        temp2.*sin(-W*t    + eps ) );
        Ux      =     -sum(     K.*temp2.*sin(-W*t    + eps ) );
        Uz      =      sum(     K.*temp2.*cos(-W*t    + eps ) );
        dA(i,j) =  Ux*U(i,j) + Uz*Wvel + dA(i,j);
    end
end
Utot = U + dU; 
Atot = A + dA;
SEC.Wneg= Wneg;   SEC.Dneg= Dneg;
SEC.Kneg= Kneg;   SEC.Eneg= Eneg;