function [Utot,Atot,SEC] = K3second(SEC,U,A,Tvec,Zvec,hlin,nr)
% Calculates second order kinematic at finite water
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
g  = 9.81;
h1 = hlin;
h2 = SEC.h;
K1 = SEC.K;
K2 = SEC.K2;
W  = SEC.W;
Za = SEC.Za;
eps= SEC.eps;
% Matrices:
    Ppos = zeros(length(W)); Pneg = Ppos; Wpos = Ppos; Wneg = Ppos; 
    Epos = Ppos;             Eneg = Ppos; Kpos = Ppos; Kneg = Ppos;
    for i = 1:length(W)
        for j = 1:length(W)
        wi =  W(i); wj =  W(j);
        ki = K2(i); kj = K2(j);  % directly from equation 3.24 in Birknes
        temp      =  g^2*ki*kj/( 2*wi*wj)-(wi^2+wj^2+wi*wj)/4 + ...
                     g^2*(wi*kj^2+wj*ki^2)/( 4*wi*wj*(wi+wj));
        Ppos(i,j) = -temp / (wi+wj-g*abs(ki+kj)/(wi+wj)*tanh(abs(ki+kj)*h2));
        temp      = -g^2*ki*kj/(-2*wi*wj)-(wi^2+wj^2-wi*wj)/4 + ...
                     g^2*(wi*kj^2-wj*ki^2)/(-4*wi*wj*(wi-wj));
        Pneg(i,j) = -temp / (wi-wj-g*abs(ki-kj)/(wi-wj)*tanh(abs(ki-kj)*h2));
        Wpos(i,j) =      W(i) +   W(j);
        Wneg(i,j) =      W(i) -   W(j);
        Epos(i,j) =    eps(i) + eps(j);
        Eneg(i,j) =    eps(i) - eps(j);
        Kpos(i,j) =     K2(i) +   K2(j);
        Kneg(i,j) =     K2(i) -   K2(j);
        end
    end
    Pneg(1:length(W)+1:end) = 0;
    dU = zeros(length(Zvec),length(Tvec)); 
    dA = dU;
for i = 1:length(Zvec)
    z = Zvec(i); [nr z]
    temp1 = Kpos.*Ppos.*cosh(abs(Kpos)*(z+h2))./cosh(abs(Kpos)*h2);
    temp2 = Kneg.*Pneg.*cosh(abs(Kneg)*(z+h2))./cosh(abs(Kneg)*h2); 
    temp3 = W.*Za./sinh(K1*h1);
    if z > 0; break; end
    for j = 1:length(Tvec)
        t       =   Tvec(j);
        % Second order horizontal velocity correction
        dU(i,j) =  -Za* (        temp1.*cos(-Wpos*t + Epos)   )  *Za';
        dA(i,j) =  -Za* (  Wpos.*temp1.*sin(-Wpos*t + Epos)   )  *Za';
        dU(i,j) =  -Za* (        temp2.*cos(-Wneg*t + Eneg)   )  *Za' + dU(i,j);
        dA(i,j) =  -Za* (  Wneg.*temp2.*sin(-Wneg*t + Eneg)   )  *Za' + dA(i,j);
        Wvel    =    sum(        temp3.*sinh(K1*(z+h1)).*sin(-W*t+eps) );
        Ux      =   -sum(    K1.*temp3.*cosh(K1*(z+h1)).*sin(-W*t+eps) );
        Uz      =    sum(    K1.*temp3.*sinh(K1*(z+h1)).*cos(-W*t+eps) );
        dA(i,j) =  Ux*U(i,j) + Uz*Wvel + dA(i,j);
    end
end
Utot = U + dU; 
Atot = A + dA;
SEC.Wneg = Wneg; SEC.Wpos = Wpos;
SEC.Pneg = Pneg; SEC.Ppos = Ppos;
SEC.Kneg = Kneg; SEC.Kpos = Kpos;
SEC.Eneg = Eneg; SEC.Epos = Epos;