function [Utot,Atot] = K4extrapolation1(ETA,U,A,Tvec,Zvec,h,nr)
% Extrapolation: linear kinematics under wave, finite water depth
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Get variables
eps  = ETA.eps;      W = ETA.W;   
K    = ETA.K;       Za = ETA.Za;
Usur = U(1,:)*0;  Asur = Usur;    % Kinematic at linear surface
% Calculate
temp = W.*Za.*cosh(K*h)./sinh(K*h);  % at z = 0
for j = 1:length(Tvec)
    t   = Tvec(j); [nr t]
    % Linear values at z = 0
    U0  = sum(   temp.*cos(-W*t + eps));
	A0  = sum(W.*temp.*sin(-W*t + eps));
    for i = 1:length(Zvec)
        if     Zvec(i) > ETA.linear(j) 
          U(i,j) = 0;  A(i,j) = 0;  % point out of water, delete kinematic
        elseif Zvec(i) < 0          % in water, below z = 0, no change!
        else                        % point is in water, but above z = 0
          U(i,j) = U0; A(i,j) = A0;
        end
    end
    if ETA.linear(j) < 0
        Usur(j) = sum(   W.*Za.*cosh(K*(ETA.linear(j) +h))./sinh(K*h).*cos(-W*t + eps));   %Velocity at surface
        Asur(j) = sum(W.^2.*Za.*cosh(K*(ETA.linear(j) +h))./sinh(K*h).*sin(-W*t + eps));   %Acceleration at surface
    else
        Usur(j) = U0;
        Asur(j) = A0;
    end
end
Utot = [Usur ; U]; 
Atot = [Asur ; A];