% K5extrapolation2.m
%% Extrapolation: second order kinematics under wave, finite water depth
h = h1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Za = SEC.Za;  eps = SEC.eps;
W  = SEC.W;   K   = SEC.K;
% Get variables
U    = VEL.deep2;    A    = ACC.deep2;    % Total deep second order kinematic!
Usur = U(1,:)*0;     Asur = Usur;         % Kinematic at linear surface                            % Acceleration at linear surface
Wneg = SECd.Wneg;   Dneg = SECd.Dneg;
Eneg = SECd.Eneg;   Kneg = SECd.Kneg;
% Calculate
temp1 = W.*Za;      % .*exp(K*0)
for j = 1:length(Tvec)
    t   = Tvec(j); [nr t]
    % Linear values at z = 0
    U0  = sum(       temp1.*cos(-W*t + eps) );
	A0  = sum(    W.*temp1.*sin(-W*t + eps) );
    W0  = sum(       temp1.*sin(-W*t + eps) );
    Ux0 =-sum( K.*   temp1.*sin(-W*t + eps) );
    Uz0 = sum( K.*   temp1.*cos(-W*t + eps) );        
    Az0 = sum( K.*W.*temp1.*sin(-W*t + eps) );
    % Second order correction at z = 0
    dU0 =  -Za* (            Dneg.*cos(-Wneg*t + Eneg)   )  *Za';
    dA0 =  -Za* (      Wneg.*Dneg.*sin(-Wneg*t + Eneg)   )  *Za';
    dA0 = Ux0*U0 + Uz0*W0 + dA0;
    for i = 1:length(Zvec)
        z = Zvec(i);
        if     Zvec(i) > ETA.linear(j)
          U(i,j) = 0;  A(i,j) = 0;  % point out of water, delete kinematic
        elseif Zvec(i) < 0          % in water, below z = 0, no change!
        else                        % point is in water, but above z = 0
          U(i,j) = U0 + dU0 + z*Uz0;               % U(i,j) = 0
          A(i,j) = A0 + dA0 + z*Az0;               % A(i,j) = 0
        end
    end
    if ETA.linear(j) < 0
        Usur(j) = sum(   W.*Za.*cosh(K*(ETA.linear(j) +h))./sinh(K*h).*cos(-W*t + eps))+dU0;   % neglect second order
        Asur(j) = sum(W.^2.*Za.*cosh(K*(ETA.linear(j) +h))./sinh(K*h).*sin(-W*t + eps))+dA0;   % neglect second order
    else
        Usur(j) = U0 + dU0 + ETA.linear(j)*Uz0;
        Asur(j) = A0 + dA0 + ETA.linear(j)*Az0; 
    end
end
VEL.expol2 = [Usur ; U]; 
ACC.expol2 = [Asur ; A];
clear Ux0 Uz0 U0 A0 W0 dU0 dA0 temp1 temp3 U A Az0 Uz0 Wneg Dneg i j z t Usur Asur