% K6extrapolation3.m
%% Extrapolation: second order kinematics under wave, finite water depth
h = h1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Za = SEC.Za;  eps = SEC.eps;
W  = SEC.W;   
K  = SEC.K; % "linear" wave numbers use h1, and cutted to Stansberg
U    = VEL.second;   A    = ACC.second;   % Total second order kinematic!
Usur = U(1,:)*0;     Asur = Usur;         % Kinematic at linear surface                          % Acceleration at linear surface
Wneg = SEC.Wneg;  % All these use "2nd order" wave numbers of h2
Wpos = SEC.Wpos;
Pneg = SEC.Pneg;
Ppos = SEC.Ppos;
Kneg = SEC.Kneg;
Kpos = SEC.Kpos;
Eneg = SEC.Eneg;
Epos = SEC.Epos;
% Calculate
temp1 = Kpos.*Ppos; % *cosh/cosh
temp2 = Kneg.*Pneg; % *cosh/cosh
temp3 = W.*Za./sinh(K*h);
for j = 1:length(Tvec)
    t   = Tvec(j); [nr t]
    % Linear values at z = 0
    U0  = sum(       temp3.*cosh(K*h).*cos(-W*t + eps) );
	A0  = sum(    W.*temp3.*cosh(K*h).*sin(-W*t + eps) );
    W0  = sum(       temp3.*sinh(K*h).*sin(-W*t + eps) );
    Ux0 =-sum( K.*   temp3.*cosh(K*h).*sin(-W*t + eps) );
    Uz0 = sum( K.*   temp3.*sinh(K*h).*cos(-W*t + eps) );        
    Az0 = sum( K.*W.*temp3.*cosh(K*h).*sin(-W*t + eps) );
    % Second order correction at z = 0
    dU0 =  -Za* (            temp1.*cos(-Wpos*t + Epos)   )  *Za';
    dA0 =  -Za* (      Wpos.*temp1.*sin(-Wpos*t + Epos)   )  *Za';
    dU0 =  -Za* (            temp2.*cos(-Wneg*t + Eneg)   )  *Za' + dU0;
    dA0 =  -Za* (      Wneg.*temp2.*sin(-Wneg*t + Eneg)   )  *Za' + dA0;
    dA0 = Ux0*U0 + Uz0*W0 + dA0;     
    for i = 1:length(Zvec)
        z = Zvec(i);
        if     Zvec(i) > ETA.linear(j)
          U(i,j) = 0;  A(i,j) = 0;  % point out of water, delete kinematic
        elseif Zvec(i) < 0          % in water, below z = 0, no change!
        else                        % point is in water, but above z = 0
          U(i,j) = U0 + dU0 + z*Uz0;               % U(i,j) = 0
          A(i,j) = A0 + dA0 + z*Az0;               % A(i,j) = 0
        end
    end
    if ETA.linear(j) < 0
        Usur(j) = sum(   W.*Za.*cosh(K*(ETA.linear(j) +h))./sinh(K*h).*cos(-W*t + eps))+dU0;   % neglect second order variation
        Asur(j) = sum(W.^2.*Za.*cosh(K*(ETA.linear(j) +h))./sinh(K*h).*sin(-W*t + eps))+dA0;   % neglect second order variation
    else
        Usur(j) = U0 + dU0 + ETA.linear(j)*Uz0;
        Asur(j) = A0 + dA0 + ETA.linear(j)*Az0; 
    end
end
VEL.expol3 = [Usur ; U]; 
ACC.expol3 = [Asur ; A];
clear Ux0 Uz0 U0 A0 W0 dU0 dA0 temp1 temp3 U A Az0 Wneg Pneg Wpos Ppos Eneg Epos Kneg Kpos i j z t Usur Asur