function [U,A] = Kwheeler(Tvec,Zvec,h,eta,U,A)
% Script calculating Wheeler stretching to eta of kinematic U and A
%  call:  kinematics

temp = max(find(Zvec<=0));  % must always calculate kinematics close to z=0!
Usur = U(temp,:);
Asur = A(temp,:);

if length(Zvec) == 1
    return
end

for j = 1:length(Tvec)
	% Data points in the stretched domain
    Znew = Zvec*(1+eta(j)/h) + eta(j);
    % Interpolate this information to our nodes
    U(:,j) = spline(Znew,U(:,j),Zvec);
    A(:,j) = spline(Znew,A(:,j),Zvec);
    % Lowest point above surface, set U and A to zero:
    temp = min(find(Zvec>eta(j)));
    U(temp:end,j) = 0;
    A(temp:end,j) = 0;
end

U = [Usur; U];
A = [Asur; A];