function [S,W] = WaveSpectra(Hs,Tp,Tvec,Wmax,gam)
% JONSWAP Wave spectra, from Tvec bt DFT relation, cutting from below and
% create fading
cd ..;
g = 9.81;

%% Create needed frequencies from Tvec
dt = Tvec(2)-Tvec(1);
N  = 2*ceil(length(Tvec)/2);  % N must be even!
W  = linspace(0,pi/dt,N/2+1); % complete to Nyquist

%% Calculate spectra:
T = 2*pi./W;                      % Wave periods
F = W/(2*pi);                     % Wave frequencies
% JONSWAP
    a    = 5*(Hs^2/Tp^4/g^2)*(1-0.287*log(gam))*pi^4;
    sigma= 0.07;
for i = 1:length(W)
	w = W(i);
    f = F(i);
	if w > 2*pi/Tp; 
        sigma = 0.09; 
	end
    S(i)   = a*g^2*w^(-5)*exp(-5/4*(Tp*f)^(-4)  )* ... 
                      gam^exp(  -(Tp*f-1)^2/   (2*sigma^2)  );  
end
clear w f
S(1) = 0;

%% Cut off lower part of spectra
temp = mean(S); 
i    = 2;
while S(i) < temp/10^9
	i = i+1;
end
W = W(i:end); 
S = S(i:end);

%% Cut spectra at Wmax, if: Wny > Wmax
Nny  = length(W);
Nmax = min(find(W>=Wmax));
if isempty(Nmax) == 0
    % cut off energy after the given Wmax
    W = W(1:Nmax);
    S = S(1:Nmax);
    % Create fading!
    N = min([ceil(Nmax/4) Nny-Nmax]);
    W = [W          W(end)+(W(2)-W(1))*(1:N)];
    S = [S(1:end-1) linspace(S(end),0,  N+1)];
end