function [VEL, ACC] = kinematics(Tvec,Zvec,hh,ETA,choice,nr)
%% Create irregular wave kinematics
%   1      2        3        4        5       6         7       8
%linear  %deep2  %second  %expol1  %expol2  %expol3 %wheel1  %wheel2

if length(hh) == 1
    h1 = hh;        h2 = hh;
else
    h1 = hh(1);     h2 = hh(2);
end
clear hh
if find(choice==0)
    VEL = 0; ACC = 0; return
end

%% Linear
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==0))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    [VEL.linear,ACC.linear] = K1linear(ETA,Tvec,Zvec,h1,nr);
end

%% Cut vectors for second order process, choice = 2 & 3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
temp1 = 1-isempty(find(choice==2)); temp2 = 1-isempty(find(choice==3));
temp3 = 1-isempty(find(choice==5)); temp4 = 1-isempty(find(choice==6));
if temp1 || temp2 || temp3 || temp4; clear temp1 temp2 temp3 temp4
    [SEC.Za,SEC.W] = WaveSpectra2nd(ETA.Za,ETA.W,ETA.Hs,2);
    temp    = length(SEC.W);    
    SEC.eps = ETA.eps(1:temp);  
    SEC.h   = h2;
    SEC.K   = ETA.K(1:temp);            % "linear" Wave numbers use h1
    cd ..; cd diverse;
    SEC.K2  = wave_number(SEC.W,h2);    % "2nd order" Wave numbers use h2
    cd irregular_sea
end
%% Second order deep water kinematics below surface
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
temp1 = 1-isempty(find(choice==2)); temp2 = 1-isempty(find(choice==5));
if temp1 || temp2; clear temp1 temp2
    [Ulin,Alin]     = K1linear(SEC,Tvec,Zvec,h1,nr);
    [VEL.deep2,ACC.deep2,SECd] =  K2deep2(SEC,Ulin,Alin,Tvec,Zvec,h1,nr);
    clear Ulin ALin
end
%% Second order finite water kinematics below surface (z = 0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
temp1 = 1-isempty(find(choice==3));  temp2 = 1-isempty(find(choice==6));
if temp1 || temp2; clear temp1 temp2
    [Ulin,Alin]     = K1linear(SEC,Tvec,Zvec,h1,nr);
    [VEL.second,ACC.second,SEC] = K3second(SEC,Ulin,Alin,Tvec,Zvec,h1,nr);
    clear Ulin ALin
end

%% Extrapolation: linear kinematics under wave, finite water depth
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==4)) == 0
    [VEL.expol1,ACC.expol1] = K4extrapolation1(ETA,VEL.linear,ACC.linear,Tvec,Zvec,h1,nr);
end

%% Extrapolation: second order kinematics under wave, finite water depth
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==5)) == 0
    K5extrapolation2; % extrapolation of deep  2nd order theory
end

%% Extrapolation: second order kinematics under wave, finite water depth
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==6)) == 0
    K6extrapolation3; % extrapolation of finite 2nd order theory
end

%% Wheeler: 1st order kinematics to 1st order surface
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==7)) == 0; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    [U,A] = Kwheeler(Tvec,Zvec,h1,ETA.linear,VEL.linear,ACC.linear);
    VEL.wheel1 = U;
    ACC.wheel1 = A;
end

%% Wheeler: 1st order kinematics to 2nd order surface
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==8)) == 0; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    [U,A] = Kwheeler(Tvec,Zvec,h1,ETA.second,VEL.linear,ACC.linear);
    VEL.wheel2 = U;
    ACC.wheel2 = A;
end
cd ..