function ETA = wave_profile(Tvec,W,S,hh,Hs,choice)
% Wave: Z = Za*cos(k*x - w*t + eps)
%  1           2                 3
% linear    %2nd order deep   %2nd order finite
if length(hh) == 1
    h1 = hh;        h2 = hh;
else
    h1 = hh(1);     h2 = hh(2);
end
cd ..;  cd diverse;
K = wave_number(W,h1);  % Wave numbers

% Waves
dW  = W(2)-W(1);                % evenly spaced spectral components
g   = 9.81;
Za  = sqrt(2*S*dW);             % amplitudes from spectrum
eps = 2*pi*rand(1,length(W));   % random phase angles, the seed is set under input
% Save variables
ETA.eps = eps;   ETA.W = W;    
ETA.Za  = Za;    ETA.K = K;
ETA.Hs  = Hs;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==1))==0
% Linear surface elevation
    for i = 1:length(Tvec)
    	t = Tvec(i);
        % Wave profile and steepness
    	Z(i)   =  sum(   Za.*cos(-W*t + eps));
       %Zx(i)  =  sum(K.*Za.*cos(-W*t + eps));
    end
    ETA.linear = Z;
end









%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Cut vectors for second order process
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cd irregular_sea
[Za,W] = WaveSpectra2nd(Za,W,Hs,2); % cut spectra automatically to sqrt(2*g/Hs)
temp   = length(W);
eps    = eps(1:temp);
cd ..;  cd diverse;
K = wave_number(W,h2);  % Wave numbers
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create linear surface elevation
Zlin = Tvec*0;
for i = 1:length(Tvec)
	t = Tvec(i);
	% Wave profile and steepness
	Zlin(i) =  sum(   Za.*cos(-W*t + eps));
end
h = h2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==2)) == 0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Second order surface elevation at deep water
    % Deep water dispersion
    Ktemp = K;      % save finite water values
    K     = W.^2/g;
    % 2nd order sea elevation transfer functions, and 
    % sum- and difference- frequency and phase angles
    % flger Johannessen 2010, Calculation of kinematics under steep waves
    Emaj = zeros(length(W)); Emin = Emaj; Wpos = Emaj; Wneg = Emaj; 
    Epos = Emaj;             Eneg = Emaj; Kpos = Emaj; Kneg = Emaj;
    for i = 1:length(W)
        for j = 1:length(W)
        Emaj(i,j) =  1/4*   (K(i) +   K(j));
        Emin(i,j) = -1/4*abs(K(i) -   K(j)); % absolut value only here to create the wanted transfer function!
        Wpos(i,j) =          W(i) +   W(j) ;
        Wneg(i,j) =          W(i) -   W(j) ; % not absolut value!
        Epos(i,j) =        eps(i) + eps(j) ;
        Eneg(i,j) =        eps(i) - eps(j) ;
        end
    end
    % Second order sea surface correction
    for i = 1:length(Tvec)
        t      =   Tvec(i);
        dZ2(i) =   Za *( (Emaj.*cos(-Wpos*t + Epos))*Za');...
                 - Za *( (Emin.*cos(-Wneg*t + Eneg))*Za')   ;
    end 
    ETA.deep2   = Zlin+dZ2;
    SECOND.Zlin = Zlin;
    % Get back finite water values
    K = Ktemp;
    clear Ktemp Emaj Emin Wpos Wneg Epos Eneg Kpos Kneg dZ2
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isempty(find(choice==3)) == 0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Second order surface elevation at finite water
    % Basert p Master av Birknes
    % 2nd order sea elevation transfer functions, and 
    % sum- and difference- frequency and phase angles
    Hpos = zeros(length(W)); Hneg = Hpos; Wpos = Hpos; Wneg = Hpos; 
    Epos = Hpos;             Eneg = Hpos; Kpos = Hpos; Kneg = Hpos;
    for i = 1:length(W)
        wi = W(i);
        ki = K(i);
        for j = 1:length(W)
        wj = W(j);
        kj = K(j);
        
        temp      =  g*ki*kj/( 2*wi*wj)-(wi^2+wj^2+wi*wj)/(4*g) + ...
                    g*(wi*kj^2+wj*ki^2)/( 4*wi*wj*(wi+wj));
        temp      = temp / (1-g*abs(ki+kj)/(wi+wj)^2*tanh(abs(ki+kj)*h));
        Hpos(i,j) = temp - g*ki*kj/( 4*wi*wj) + (wi^2+wj^2+wi*wj)/(4*g);
        
        temp      = -g*ki*kj/(-2*wi*wj)-(wi^2+wj^2-wi*wj)/(4*g) + ...
                    g*(wi*kj^2-wj*ki^2)/(-4*wi*wj*(wi-wj));
        temp      = temp / (1-g*abs(ki-kj)/(wi-wj)^2*tanh(abs(ki-kj)*h));
        Hneg(i,j) = temp + g*ki*kj/(-4*wi*wj) + (wi^2+wj^2-wi*wj)/(4*g);
        
        Wpos(i,j) =  W(i) +   W(j) ;
        Wneg(i,j) =  W(i) -   W(j) ;
        Epos(i,j) = eps(i) + eps(j) ;
        Eneg(i,j) = eps(i) - eps(j) ;
        end
    end
    Hneg(1:length(W)+1:end) = 0;
    
    % Second order sea surface correction
    for i = 1:length(Tvec)
        t      =   Tvec(i);
        dZ2(i) =   Za *( (Hpos.*cos(-Wpos*t + Epos))*Za')...
                 + Za *( (Hneg.*cos(-Wneg*t + Eneg))*Za')   ;
    end
    ETA.second  = Zlin+dZ2;
	SECOND.Zlin = Zlin;
    clear Ppos Pneg wi wj ki kj dZ2
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%