% Waves
cd ..;

[M N]  = max(S);
N      = ceil(N*1.2);  % upper limit for Low frequencies
M      = floor(N/3);   % lower limit for Low frequencies
W0     = W(M:end);     % cutting in paramteters from wave spectra
Za0    = Za(M:end);
eps0   = eps(M:end);
N      = N - M + 1;    % Change the upper limit number in the cutted vectors
M      = length(W0);   % Length of cutted vectors
cd irregular_sea;
K0     = zhang_wavenumber(W0,Za0,h,N);
alf0   = coth(K0*h);

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of Low waves and low-low interactions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
alf = alf0(1:N); Za = Za0(1:N); K = K0(1:N); eps = eps0(1:N); W = W0(1:N);

% Matrices
for j = 1:N
    ALFj(:,j) = alf;  % different in vertical direction (j-direction, rows)
    ALFi(j,:) = alf;  % different in horizontal direction (i-direction, coloumns)
     Zaj(:,j) = Za;
     Zai(j,:) = Za;
      Wj(:,j) = W;
      Wi(j,:) = W;
      Kj(:,j) = K;
end
LAM = Wi./Wj;

temp = ALFj.*LAM.*(ALFi.^2-1) + 2*ALFi.*ALFj.*LAM.*(ALFj-ALFi) - ALFi.*(ALFj.^2-1);
temp = temp./( (ALFj-ALFi.*LAM).^2 - (1-LAM).^2  );
Bneg =  Zai.*Zaj.*Kj./(2*ALFj).*(ALFi.*LAM.^2-ALFj).*temp;
Bneg(1:N+1:end) = 0;
temp = ALFj.*LAM.*(ALFi.^2-1) + 2*ALFi.*ALFj.*LAM.*(ALFj+ALFi) + ALFi.*(ALFj.^2-1);
temp = temp./( (ALFj-ALFi.*LAM).^2 - (1+LAM).^2  );
Bpos = -Zai.*Zaj.*Kj./(2*ALFj).*(ALFi.*LAM.^2+ALFj).*temp;
Bpos(1:N+1:end) = 0;

% Calculation
% i = coloums (horizontal)
% j = rows    (coloumns)
for i = 1:length(Tvec)
    t = Tvec(i);
    for j = 1:N
        THj(:,j)    = -W*t + eps;
        THi(j,:)    = -W*t + eps;
    end
Z_L(i) = sum( Za.*cos(THi(1,:)) ... 
            + Za.^2.*K.*alf/4.*(3*alf.^2-1).*cos(2*THi(1,:)) );
Z_L(i) = sum( sum( Bneg.*cos(THj-THi) + Bpos.*cos(THj+THi) )) + Z_L(i);
end

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of high frequency wave interactions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
alf = alf0(N+1:M); Za= Za0(N+1:M); K = K0(N+1:M); eps = eps0(N+1:M); W = W0(N+1:M);

clear Emaj Emin
for j = 1:M-N
    for i = 1:M-N
         Emaj(j,i) =  1/4*   (K(j) +   K(i));
         Emin(j,i) = -1/4*abs(K(j) -   K(i)); % absolute value only here to create the wanted transfer function!
    end
end
Emaj(1:M-N+1:end) = 0;
Emin(1:M-N+1:end) = 0;

clear THj THi
for i = 1:length(Tvec)
t = Tvec(i);
    for j = 1:M-N
        THj(:,j) = -W*t + eps;
        THi(j,:) = -W*t + eps;
    end

Z_SS(i) =   Za *( (Emaj.*cos(THj+THi))* Za')...
          + Za *( (Emin.*cos(THj-THi))* Za')   ;
end
   
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate the interaction between lower and upper range   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
alf = alf0; Za = Za0; K = K0; eps = eps0; W = W0;

clear THj THi Wi Wj Zai Zaj Ki Kj ALFi ALFj

% Update all matrices
for j = 1:M-N            % rows = high frequencies
    Zai(j,:) = Za0(1:N); % for use in sum of low frequencies
    Ki(j,:)  = K0(1:N);
    ALFi(j,:)= alf(1:N);
    Wi(j,:)  = W0(1:N);
end  
for j = 1:N
    Wj(:,j)  = W0(N+1:M);
end
LAM = Wi./Wj;

Z_S = zeros(1,length(Tvec));
for i = 1:length(Tvec)
    
    t = Tvec(i);
    for j = 1:(M-N)      % for use in sum of low frequencie
        THi(j,:)    = -W(1:N)*t + eps(1:N);
    end
    
    THj = -W(N+1:M)'*t + eps(N+1:M)';
    
    % summation over low frequencies
    temp   = (2-ALFi.*LAM).^2 - LAM.^2;
    temp   = 1 + LAM.*(ALFi-1./ALFi).*(2-ALFi.*LAM-ALFi.*LAM.^3)./temp;
    THhhj  = THj + K(N+1:M)'.*sum( Zai.*ALFi.*sin(THi).*temp   ,2); 
    
    temp   = (2-ALFi.*LAM).^2 - LAM.^2;
    temp   = 1./ALFi - (ALFi-1./ALFi).*(LAM.^2 + 2*ALFi.*LAM - 3)./temp;
    faj    = 1 + sum(  Zai.*Ki.*cos(THi).*temp   ,2);
    
    % summation over high frequencies
    Z_S(i) = sum(faj.*Za(N+1:M)'.*cos(THhhj)) + sum( Za(N+1:M)'.^2.*K(N+1:M)'/2.*cos(THhhj) );
end