function embedDNV(UI)
% Forced embedding
% Calls: WaveSpectra.m
%        stream.m
%        wave_number.m
%        wave_profile.m
%        kinematics.m
%        morison2.m
%        morisonL.m

cd ..; home = pwd;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% User input %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h       = UI.h;
D       = UI.D;
Cm      = UI.Cm;
Cd      = UI.Cd;
Zvec    = UI.Zvec;
time    = UI.time;
dt      = UI.dt;
gam     = UI.gam;
Hs      = UI.Hs;
Tp      = UI.Tp;
NR      = UI.seed;
optWave = UI.optWave;
optKine = UI.optKine;
rho     = UI.rho;
g       = UI.g;
H       = UI.H;
T       = UI.T;
NORDER  = UI.ORDER;    
Wmax    = UI.Wmax;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if optKine==8
    if isempty(find(optWave==3))
        optWave = [optWave 3];
    end
end
while length(optKine)>1 || optKine < 4
    fprintf('\n\nChoose kinematic 4 to 8\n')
    optKine=input('optKine = ');
end  

%% Stream function
Tvec = [0:dt:T*4];
cd regular;
STR  = stream(Tvec,Zvec,H,T,h,NORDER);
temp = sign(STR.Z(1:end-1).*STR.Z(2:end)); 
temp = [(temp-1)/(-2) 0];
temp = temp.*(sign(STR.Z)-1)/(-2);         % up-crossing
loc  = find(temp==1);
STR.Z = STR.Z( 1, (loc(1)+1):loc(2) );
STR.U = STR.U( :, (loc(1)+1):loc(2) );
STR.A = STR.A( :, (loc(1)+1):loc(2) );

%% Wave spectra
Tvec = [0:dt:time];
cd irregular_sea;
[S,W] = WaveSpectra(Hs,Tp,[0:dt:time*10],Wmax,gam);
cd diverse;
K = wave_number(W,h);  % Wave numbers

%% Realization
temp = {'linear' 'deep2' 'second' 'expol1' 'expol2' 'expol3' 'wheel1' 'wheel2'};
STR_KIN = temp{optKine};
for i = NR
rng(i); % seed
% Wave profiles
cd irregular_sea;
ETA = wave_profile(Tvec,W,S,h,Hs,optWave);
% Wave kinematics
cd irregular_sea;
[VEL,ACC] = kinematics(Tvec,Zvec,h,ETA,optKine,i);
Z = ETA.linear;
A = ACC.(STR_KIN);
U = VEL.(STR_KIN);

% Cutting in the realization!    
    temp = sign(Z(1:end-1).*Z(2:end));     % crossing!
    temp = [(temp-1)/(-2) 0];
    temp = temp.*(sign(Z)-1)/(-2);         % up-crossing
    loc  = find(temp==1);                  % step before positive  
    temp = min(find(Tvec(loc)>time/2));
    pos(i,:) = [loc(temp) loc(temp)+1];

Zmat(i,:)                 = [Z(1,1:pos(i,1)) STR.Z Z(1,pos(i,2):end)];
Umat.(['run' num2str(i)]) = [U(:,1:pos(i,1)) STR.U U(:,pos(i,2):end)];
Amat.(['run' num2str(i)]) = [A(:,1:pos(i,1)) STR.A A(:,pos(i,2):end)];
% Forces
cd diverse;
FM.(['run' num2str(i)]) = morison2(Cm,Cd,D,h,Zvec,Zmat(i,:), ...
                    Umat.(['run' num2str(i)]),Amat.(['run' num2str(i)]));
cd diverse
Fdist.(['run' num2str(i)])= morisonL(Cm,Cd,D,h,Zvec,Zmat(i,:), ...
                    Umat.(['run' num2str(i)]),Amat.(['run' num2str(i)])); 
end

%% Save variables
INFO.h   = h;      INFO.HsTpGam = [Hs Tp gam];
INFO.Zvec= Zvec;   INFO.dt = dt; INFO.time = time; 
INFO.WS  = [W; S]; INFO.CmCd = [Cm Cd];
INFO.H   = H;      INFO.T   = T;
INFO.time= (length(Zmat(1,:))-1)*dt;  INFO.timeOrg=time;
INFO.gam = gam;
INFO.Zvec= Zvec; 
INFO.seed= NR;
type = ['Forced Embedding: ' STR_KIN ' kinematic'];
cd(home)
save('ForcedEmbed','type','INFO','STR','Zmat','Umat','Amat','FM','Fdist');