function embedFIT(UI)
% Smooth embedding
% Calls: !embedding2.exe
%        wave_number.m
%        wave_profile.m
%        kinematics.m
%        stream_kinematics.m
%        morison2.m
%        morisonL.m
%        ExtractSeries.m
%        read_output2.m
cd ..; home = pwd;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% User input %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h       = UI.h;
D       = UI.D;
Cm      = UI.Cm;
Cd      = UI.Cd;
Zvec    = UI.Zvec;
time    = UI.time;
Tcutoff = UI.Tcutoff;
dt      = UI.dt;
gam     = UI.gam;
Hs      = UI.Hs;
Tp      = UI.Tp;
NR      = UI.seed;
optWave = UI.optWave;
optKine = UI.optKine;
optExtr = UI.optExtr;        % 1=>Ac+min(At), 2=>Ac+mean(At), 3=>H
rho     = UI.rho;
g       = UI.g;
H       = UI.H;
T       = UI.T;
NORDER  = UI.ORDER;    
Wmax    = UI.Wmax;
%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if optKine==8
    if isempty(find(optWave==3))
        optWave = [optWave 3];
    end
end
while length(optKine)>1 || optKine < 4
    fprintf('\n\nChoose kinematic 4 to 8\n')
    optKine=input('optKine = ');
end 
if optExtr == 1; optExtr = 3; end
if optExtr == 3; optExtr = 1; end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cd dean_fortran;
FID = fopen('embedding_input.dat','w'); cd ..;
nr   = length(NR);
NDY  = 20; % number of points to calculate kinematics in dean.f
% Write: depth, number of points for VELOC, number of realizations, NORDER
fprintf(FID,[num2str(h*3.28084) '     ' num2str(NDY) '     ' ...
             num2str(nr)        '     ' num2str(NORDER) '\n']);
kinSTR = {'linear';'deep2';'second';'expol1';'expol2';'expol3';'wheel1';'wheel2'};
kinSTR = kinSTR{optKine};
etaSTR = {'linear';'deep2';'second'};
etaSTR = etaSTR{optWave};
% Wave spectra
cd irregular_sea;
Tvec  = 0:dt:time;
[S,W] = WaveSpectra(Hs,Tp,Tvec,Wmax,gam);
temp = floor(Tcutoff/dt);
Zmat = zeros(temp*2+1,nr);
Tvec0= [-Tvec(1+temp:-1:2) Tvec Tvec(end)+Tvec(2:temp+1)];  % extended time series
cd diverse;
K = wave_number(W,h);  % Wave numbers
% Lage realisasjoner med utregnet spekter og blgetall, runs = NR 
for i = NR
rng(i); % seed
% Wave profiles
cd irregular_sea;
ETA = wave_profile(Tvec,W,S,h,Hs,optWave);% Wave kinematics
% Embedded stream function
cd embedding;
RES    = ExtractSeries(Tvec,ETA.(etaSTR),Tcutoff,dt,optExtr);
    fprintf(FID,[num2str(RES.H*3.28084) '     ' num2str(RES.T) '\n']);
% Wave kinematics
cd irregular_sea;
[VEL,ACC] = kinematics(RES.Tvec,Zvec,h,ETA,optKine,i);
Z = ETA.linear;
A = ACC.(kinSTR);
U = VEL.(kinSTR);
% Create MATRICES of results to work with later
Zirr(i,:)                 = RES.Z;
Hirr(i,1)                 = RES.H;
Tirr(i,1)                 = RES.T;
Uirr.(['run' num2str(i)]) = VEL.(kinSTR);
Airr.(['run' num2str(i)]) = ACC.(kinSTR);
end
close all;

%% Call Executable
cd dean_fortran
!embedding2.exe
cd ..
%% Read output from NAG fortran 
cd embedding;
NR
STAT = read_output2(NR,NORDER);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Calculate and blend in stream function solutions %%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Dean Elevation and Kinematics
temp = length(Zirr(1,:));
N0   = ceil(temp/2);
Tvec = (linspace(1,temp,temp)-N0)*dt; % Tvec with 0 in the middle
Znew = zeros(length(NR),length(Tvec));
j = 0;
for i = NR
j = j+1;
i
cd regular;
KIN = stream_kinematics(STAT.ETA(:,[1 j+1]),STAT.COEFF(:,j), ...
                                          STAT.T(j),Zvec,Tvec,h);                                      
% Create blended solution
cd embedding;
Znew(i,:)                 = blend(Tvec,Tirr(i),Zirr(i,:)                ,KIN.Z);
Unew.(['run' num2str(i)]) = blend(Tvec,Tirr(i),Uirr.(['run' num2str(i)]),KIN.U);
Anew.(['run' num2str(i)]) = blend(Tvec,Tirr(i),Airr.(['run' num2str(i)]),KIN.A);
cd ..;
% Forces
if STAT.H(i)>0
    cd diverse;
    FM.(['run' num2str(i)]) = morison2(Cm,Cd,D,h,Zvec,Znew(i,:), ...
                        Unew.(['run' num2str(i)]),Anew.(['run' num2str(i)]));
    cd diverse
    Fdist.(['run' num2str(i)])= morisonL(Cm,Cd,D,h,Zvec,Znew(i,:), ...
                        Unew.(['run' num2str(i)]),Anew.(['run' num2str(i)])); 
end
end

%% Save variables
INFO.h   = h;      INFO.HsTpGam = [Hs Tp gam];
INFO.Zvec= Zvec;   INFO.dt = dt; INFO.time = time; 
INFO.WS  = [W; S]; INFO.CmCd = [Cm Cd];
INFO.H   = H;      INFO.T   = T;
INFO.time= (length(Znew(1,:))-1)*dt;  INFO.timeOrg=time;
INFO.seed= NR;
INFO.optExtr=optExtr;
type = ['Fit Embedding: ' kinSTR ' kinematic'];
cd(home)
save('FitEmbed','INFO','Tirr','Hirr','Zirr','Uirr','Airr','Znew','Unew','Anew','STAT','FM','Fdist');