%% Main regular
function embedMIX(UI)
% Mixed approach embedding
% Calls: stream.m
%        wave_number.m
%        wave_profile.m
%        kinematics.m
%        stream_kinematics.m
%        morison2.m
%        morisonL.m
%        ExtractSeries.m
%        blend2.m

cd ..; home = pwd;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% User input %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
h       = UI.h;
D       = UI.D;
Cm      = UI.Cm;
Cd      = UI.Cd;
Zvec    = UI.Zvec;
time    = UI.time;
dt      = UI.dt;
Tcutoff = UI.Tcutoff;
gam     = UI.gam;
Hs      = UI.Hs;
Tp      = UI.Tp;
NR      = UI.seed;
optWave = UI.optWave;
optKine = UI.optKine;
optExtr = UI.optExtr;        % 1=>Ac+min(At), 2=>Ac+mean(At), 3=>H
rho     = UI.rho;
g       = UI.g;
H       = UI.H;
T       = UI.T;
NORDER  = UI.ORDER;    
Wmax    = UI.Wmax;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if optKine==8
    if isempty(find(optWave==3))
        optWave = [optWave 3];
    end
end
while length(optKine)>1 || optKine < 4
    fprintf('\n\nChoose kinematic 4 to 8\n')
    optKine=input('optKine = ');
end  
           
%% Stream function
temp = floor(Tcutoff/dt);
Tvec = (-temp:temp)*dt; % Tvec with 0 in the middle
cd(home); cd regular;
STR  = stream(Tvec,Zvec,H,T,h,NORDER);

%% Irregular sea calculation     
kinSTR = {'linear';'deep2';'second';'expol1';'expol2';'expol3';'wheel1';'wheel2'};
kinSTR = kinSTR{optKine};
etaSTR = {'linear';'deep2';'second'};
etaSTR = etaSTR{optWave};
% Wave spectra
cd irregular_sea;
Tvec  = 0:dt:time;
[S,W] = WaveSpectra(Hs,Tp,Tvec,Wmax,gam);
cd diverse;
K = wave_number(W,h);  % Wave numbers
% Extend time vector
temp = floor(Tcutoff/dt);
Tvec0= [-Tvec(1+temp:-1:2) Tvec Tvec(end)+Tvec(2:temp+1)];  % extended time series
for i = NR
rng(i); % seed
% Wave profiles
cd irregular_sea;
ETA = wave_profile(Tvec0,W,S,h,Hs,optWave);     % Wave kinematics
% Embedded stream function
cd embedding;
RES = ExtractSeries(Tvec0,ETA.(etaSTR),Tcutoff,dt,optExtr);
% Wave kinematics
cd irregular_sea;
[VEL,ACC] = kinematics(RES.Tvec,Zvec,h,ETA,optKine,i);
Z = ETA.linear;
% Create MATRICES of results to work with later
Zirr(i,:)                 = RES.Z;
Tirr(i,1)                 = RES.T;
Uirr.(['run' num2str(i)]) = VEL.(kinSTR);
Airr.(['run' num2str(i)]) = ACC.(kinSTR);
end
close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Create blended solution
temp = floor(Tcutoff/dt);
Tvec = (-temp:temp)*dt; % Tvec with 0 in the middle
% Blend!
for i = NR                                
cd(home); cd embedding
Zmat(i,:)                 = blend2(Tvec,Tirr(i),Zirr(i,:)                ,T,STR.Z);
Umat.(['run' num2str(i)]) = blend2(Tvec,Tirr(i),Uirr.(['run' num2str(i)]),T,STR.U);
Amat.(['run' num2str(i)]) = blend2(Tvec,Tirr(i),Airr.(['run' num2str(i)]),T,STR.A);
% Forces
cd(home); cd diverse;
FM.(['run' num2str(i)]) = morison2(Cm,Cd,D,h,Zvec,Zmat(i,:), ...
                    Umat.(['run' num2str(i)]),Amat.(['run' num2str(i)]));
cd diverse
Fdist.(['run' num2str(i)])= morisonL(Cm,Cd,D,h,Zvec,Zmat(i,:), ...
                    Umat.(['run' num2str(i)]),Amat.(['run' num2str(i)])); 
end
%% Save variables
INFO.h   = h;      INFO.HsTpGam = [Hs Tp gam];
INFO.Zvec= Zvec;   INFO.dt = dt; INFO.time = time; 
INFO.WS  = [W; S]; INFO.CmCd = [Cm Cd];
INFO.H   = H;      INFO.T   = T;
INFO.time= (length(Zmat(1,:))-1)*dt;  INFO.timeOrg=time;
INFO.gam = gam;
INFO.Zvec= Zvec; 
INFO.seed= NR;
INFO.optExtr=optExtr;
type = ['Mixed approach Embedding: ' kinSTR ' kinematic'];
cd(home)
save('MixEmbed','type','INFO','STR','Zmat','Umat','Amat','FM','Fdist');