function mainIrregular(UI)
% Irregular sea calculation
% Calls: WaveSpectra.m
%        wave_number.m
%        wave_profile.m
%        kinematics.m
%        morison2.m
%        morisonL.m

cd ..; home = pwd;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% User input %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
hh      = UI.h;
D       = UI.D;
Cm      = UI.Cm;
Cd      = UI.Cd;
gam     = UI.gam;
Hs      = UI.Hs;
Tp      = UI.Tp;
Wmax    = UI.Wmax;
NR      = UI.seed;
Zvec    = UI.Zvec;
time    = UI.time;
dt      = UI.dt;
optWave = UI.optWave;
optKine = UI.optKine;
rho     = UI.rho;
g       = UI.g;              
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if find(optKine==8)
    if isempty(find(optWave==3))
        optWave = [optWave 3];
    end
end
%% Wave spectra
cd(home)
Tvec  = [0:dt:time];
cd irregular_sea
[S,W] = WaveSpectra(Hs,Tp,Tvec,Wmax,gam);
%% Irregular surface and kinematics
for i = NR
    rng(i); % seed
    % Wave profiles
    cd irregular_sea;
    ETA = wave_profile(Tvec,W,S,hh,Hs,optWave);
    % Wave kinematics
    cd irregular_sea;
    [VEL,ACC] = kinematics(Tvec,Zvec,hh,ETA,optKine,i);
    % write variables to save -->
    save(['run' num2str(i)],'ETA','VEL','ACC'); 
end

%% Save in structures
INFO.h   = hh;     INFO.HsTpGam = [Hs Tp gam];
INFO.Zvec= Zvec;   INFO.dt = dt; INFO.time = time; 
INFO.WS  = [W; S]; INFO.CmCd = [Cm Cd];
STR = {'linear' 'deep2' 'second' 'expol1' 'expol2' 'expol3' 'wheel1' 'wheel2'};

if find(optKine==0)
else
    cd(home);
    for i = 1:length(optKine)
    type   = [STR{optKine(i)} ' kinematic'];
    strETA = 'linear';
    temp   = find(strcmp(STR{optKine(i)},STR)==1);
    if temp==8
        strETA = 'second';
    end
    for j = NR
        temp = load(['run' num2str(j)]);
        Zmat(j,:)                 = temp.ETA.(strETA);
        Umat.(['run' num2str(j)]) = temp.VEL.(STR{optKine(i)});
        Amat.(['run' num2str(j)]) = temp.ACC.(STR{optKine(i)});
        % Loads
        cd  diverse
        FM.(['run' num2str(j)])   = morison2(Cm,Cd,D,hh(1),Zvec,Zmat(j,:),Umat.(['run' num2str(j)]),Amat.(['run' num2str(j)])); 
        cd diverse
        Fdist.(['run' num2str(j)])= morisonL(Cm,Cd,D,hh(1),Zvec,Zmat(j,:),Umat.(['run' num2str(j)]),Amat.(['run' num2str(j)])); 
    end
    save(STR{optKine(i)},'type','INFO','Zmat','Umat','Amat','FM','Fdist');
    end
    cd ..;   
end
cd(home)