%% Main regular
function mainRegular(UI)
% Wave: Z = Za*cos(k*x - w*t)
% Regular sea calculation
% Calls: WaveSpectra.m
%        wave_number.m
%        wave_linear.m
%        Kwheeler.m
%        morison2.m
%        morisonL.m
%        stokes3rd.m
%        DistProperty.m
%        stream.m

cd ..; home = pwd;
h       = UI.h;
D       = UI.D;
Cm      = UI.Cm;
Cd      = UI.Cd;
Zvec    = UI.Zvec;
time    = UI.time;
dt      = UI.dt;
optKine = UI.optKine;
rho     = UI.rho;
g       = UI.g;
H       = UI.H;
T       = UI.T;
NORDER  = UI.ORDER;

%% Time vector
Tvec = 0:dt:time;

%% Linear wave kinematics
if optKine<3
    cd regular;
    LIN = wave_linear(H,T,h,Tvec,Zvec);
    Zmat = LIN.Z;  Umat = LIN.U;  Amat = LIN.A;
    if find(optKine==2)
        cd irregular_sea
        [Umat,Amat] = Kwheeler(Tvec,Zvec,h,Zmat,Umat,Amat); cd ..
    end
    INFO.k = LIN.k;
end

%% 3rd order wave kinematics
if optKine==3 || optKine==4
    cd regular;
    LIN = stokes3rd(H,T,h,Tvec,Zvec);
    Zmat = LIN.Z;  Umat = LIN.U;  Amat = LIN.A;
    if find(optKine==5)
        cd irregular_sea
        [Umat,Amat] = Kwheeler(Tvec,Zvec,h,Zmat,Umat,Amat); cd ..
    end
    INFO.k = LIN.k;
end

%% Stream function
if optKine==5
    cd regular;
    STR = stream(Tvec,Zvec,H,T,h,NORDER);
    Zmat = STR.Z;  Umat = STR.U;  Amat = STR.A;
    INFO.COEFF = STR.COEFF;
end

%% Flux
temp = 1:length(dt:dt:T);
cd diverse
flux = sum(sum(DistProperty(Zvec,Umat(:,temp),Zmat(temp)))*dt/T/h);

%% Loads
cd diverse
FM    = morison2(Cm,Cd,D,h,Zvec,Zmat,Umat,Amat); 
cd diverse
Fdist = morisonL(Cm,Cd,D,h,Zvec,Zmat,Umat,Amat); 

%% Save in structures
cd(home);
INFO.h   = h;    INFO.H = H; INFO.T   = T; 
INFO.Zvec= Zvec; INFO.dt = dt; INFO.time = time; 
INFO.CmCd= [Cm Cd];  
STR = {'linear' 'linear_stretched'  ...
       'third'  'third_stretched' 'stream_function'};
cd(home);
type = [STR{optKine} ' kinematic'];
save(STR{optKine},'type','INFO','Zmat','Umat','Amat','flux','Fdist','FM');