function THI = stokes3rd(H,T,h,Tvec,Zvec)
% Calculation of third order stokes kinematic
% Calls: wave_number.m
cd ..;
w = 2*pi/T;     
g = 9.81;
Za= H/2;

%% Wave number
cd diverse;
k = wave_number(w,h);
s = 0;
    
for j = 1:20
	eps = k*Za;

	C1  = (8*cosh(k*h)^4-8*cosh(k*h)^2+9)/( 8*sinh(k*h)^4 );
        
    B11 = 1;      % 1st order force, from 1st omega wave
    B22 = (2*cosh(k*h)^2 + 1)*cosh(k*h)/(4*sinh(k*h)^3);
	B33 = 3*(8*cosh(k*h)^6 + 1)/(64*sinh(k*h)^6);
        
    s   = eps - s^3*B33;
	lam = 2*pi/k;
    lam = lam*tanh(k*h)*(1 + s^2*C1);
	k   = 2*pi/lam;
    LAM(j,:) = [j lam];
end

A11 = 1/sinh(k*h);
A22 = 3/8/sinh(k*h)^3;
A33 = (13-4*cosh(k*h)^2)/(64*sinh(k*h)^7);
A13 = (-cosh(k*h)^2*(5*cosh(k*h)^2)+1)/(8*sinh(k*h)^5);

%% Wave profile
E1 = eps^1*B11;
E2 = eps^2*B22;
E3 = eps^3*B33;
Z1 = E1*cos(-1*w*Tvec)/k;   % 1st order surface elevation
Z2 = E2*cos(-2*w*Tvec)/k;   % 2nd
Z3 = E3*cos(-3*w*Tvec)/k;   % 3rd
THI.Z = Z1+Z2+Z3;

%% Wave kinematic
D1 = s*A11 + s^3*A13;
D2 =    s^2*A22;
D3 =         s^3*A33;
%  This is the horizontal kinematics distributed in vertical direction.
U = zeros(length(Zvec),length(Tvec));
A = U;
u = @(Tvec,z) w^1/k*cosh(k*(z+h))*( D1*cos(-1*w*Tvec) ...
                                   +D2*cos(-2*w*Tvec) +D3*cos(-3*w*Tvec));
a = @(Tvec,z) w^2/k*cosh(k*(z+h))*( D1*sin(-1*w*Tvec) ...
                                   +D2*sin(-2*w*Tvec) +D3*sin(-3*w*Tvec));
for i = 1:length(Zvec)
    z = Zvec(i);
    if z > 0; break; end
    U(i,:) = u(Tvec,z);
    A(i,:) = a(Tvec,z);
end
THI.U = U;
THI.A = A;
THI.k = k;