function KIN = stream_kinematics(eta,coeff,T,Zvec,Tvec,h)
%  WAVE KINEMATICS FROM STREAM FUNCTION
%  This function use the output from dean-fortran, with output changed to
%  metric!

cd ..;

L  = coeff(1);
cr = L/T;
k  = 2*pi/L;

% Surface elevation
Xvector = [-eta(end:-1:2,1); eta(:,1)];
Yvector = [ eta(end:-1:2,2); eta(:,2)];
cd regular;
Z = stream_wave(Xvector,Yvector,-cr*k*Tvec);

% Kinematics
U = zeros(length(Zvec)+1,length(Tvec));
A = zeros(length(Zvec)+1,length(Tvec));
N = length(coeff)-2;
J = 1:N;
B = coeff(2:end-1,1)';
for j = 1:length(Tvec)
    t     = Tvec(j);
    temp  = max(find(Zvec<=Z(j)));
    Ztemp = [Z(j) Zvec(1:temp)];
    for i = 1:length(Ztemp)
        z = Ztemp(i);
        u  = -sum(  J*k    .*B.*cosh(J*k*(z+h)).*cos(-J*k*cr*t) );
        w  = -sum(  J*k    .*B.*sinh(J*k*(z+h)).*sin(-J*k*cr*t) );
        ux =  sum( (J*k).^2.*B.*cosh(J*k*(z+h)).*sin(-J*k*cr*t) );
        uz = -sum( (J*k).^2.*B.*sinh(J*k*(z+h)).*cos(-J*k*cr*t) );
        ut = (-cr + u)*ux + w*uz;
        U(i,j) = u;
        A(i,j) = ut;
    end
end

KIN.Z = Z;
KIN.U = U;
KIN.A = A;
KIN.k = k;