function LIN = wave_linear(H,T,h,Tvec,Zvec)
% Linear Regular wave
% Wave: Z = Za*cos(k*x - w*t)
% Calls: wave_number.m

cd ..;

%% More parameters
w   = 2*pi/T;                    % Angular frequency
cd diverse;
k   = wave_number(w,h)          % Wave number
lam = 2*pi/k;                    % Wave length
Za  = H/2;                       % Wave amplitude

%% Wave profile
Z = Za*cos(-w*Tvec);

%% Wave kinematic
%  This is the horizontal force distributed in vertical direction.
U  = zeros(length(Zvec),length(Tvec));
Ut = U;
u  = @(Tvec,z) Za*w  *cosh(k*(z+h))/sinh(k*h).*cos(-w*Tvec);
ut = @(Tvec,z) Za*w^2*cosh(k*(z+h))/sinh(k*h).*sin(-w*Tvec);
for i = 1:length(Zvec)
    z = Zvec(i);
    if z > 0; break; end
    U(i,:)  = u(Tvec,z);
    Ut(i,:) = ut(Tvec,z);
end

LIN.Z = Z;
LIN.U = U;
LIN.A = Ut;
LIN.k = k;